#!/bin/sh

exec apt install \
	build-essential \
	cython3 \
	devscripts \
	git \
	pypy \
	pypy-coverage \
	pypy-dev \
	python3 \
	python3-cffi \
	python3-coverage \
	python3-dev \
	python3-pyqt5 \
	python3-pyside2.qtcore \
	python3-pyside2.qtgui \
	python3-pyside2.qtwidgets \
	python3-serial
